@@ -133,18 +133,13 @@ void reload_info(int signal);
 void exit_action(void);
 void start_action(void);
 void setup_keys(void);
-void adjust_status_size(void);
 
 /* functions */
 gint roll_timer(gpointer *data)
 {
 	int track, abs_pos;
-	if(skip_first = TRUE)
-	{
-		skip_pos = cd.cur_pos_abs;
-		skip_first = FALSE;
-	}
 
+	skip_pos = cd.cur_pos_abs;
 	skip_offset += GPOINTER_TO_INT(data);
 
 	/* make sure we display the correct time */
