@@ -18,7 +18,8 @@ GnomeUIInfo gtcd_popup_menu[] =
     {GNOME_APP_UI_SEPARATOR},
     GNOMEUIINFO_ITEM_STOCK(N_("Preferences..."), NULL, preferences, GNOME_STOCK_MENU_PREF),
     GNOMEUIINFO_ITEM_STOCK(N_("Track Editor..."), NULL, edit_window, GNOME_STOCK_MENU_PROP),
-    GNOMEUIINFO_ITEM_STOCK(N_("About..."), NULL, about_cb, GNOME_STOCK_MENU_ABOUT),
+    GNOMEUIINFO_ITEM_STOCK(N_("Help"), NULL, help, GNOME_STOCK_PIXMAP_HELP),
+    GNOMEUIINFO_ITEM_STOCK(N_("About"), NULL, about_cb, GNOME_STOCK_MENU_ABOUT),
     {GNOME_APP_UI_SEPARATOR},
     GNOMEUIINFO_ITEM_STOCK(N_("Quit"), NULL, quit_cb, GNOME_STOCK_MENU_QUIT),
     GNOMEUIINFO_END
